@@ -511,7 +511,9 @@ class EventListingView(FolderListing):
         today = DateTime()
         
         for res in self.cachedResults:
-            if res.start <= today and today <= res.end:
+            if res.start.strftime("%d/%m/%Y") == today.strftime("%d/%m/%Y"):
+                res_list.append(res)
+            elif res.start <= today and today <= res.end:
                 res_list.append(res)
         
         final_res = sorted(res_list, key=lambda x: getattr(x, "start", False), reverse=True)
@@ -523,7 +525,6 @@ class EventListingView(FolderListing):
         returns a result list for events that: today < start; Chronological order
         """
         #Cache results layzily for better performance
-         #Cache results layzily for better performance
         if self.cachedResults is None:
             self.cachedResults = self.results(batch=False, only_documented=only_documented)
         
@@ -531,7 +532,9 @@ class EventListingView(FolderListing):
         today = DateTime()
         
         for res in self.cachedResults:
-            if today < res.start:
+            if res.start.strftime("%d/%m/%Y") == today.strftime("%d/%m/%Y"):
+                pass
+            elif today < res.start:
                 res_list.append(res)
         
         #NOTE: No need to sort here since the collection is already ordered that way but it might be mor powerfull to sort anyway... for now leaving it like this for performance sake
